// index.tsx
import npmIcon from "../asset/npm.svg";
import githubIcon from "../asset/github.png";

// markup/Code.tsx
import { jsx } from "react/jsx-runtime";
var codeStyles = {
  fontFamily: "monospace",
  // Firefox has less line height otherwise.
  lineHeight: "120%",
  padding: 10,
  overflow: "auto",
  background: "#EEEEEE"
};
function Code({
  style = {},
  children,
  ...props
}) {
  return /* @__PURE__ */ jsx("pre", { style: { ...codeStyles, ...style }, ...props, children });
}

// markup/Button.tsx
import { jsx as jsx2 } from "react/jsx-runtime";
var styles = {
  background: "black",
  color: "white",
  border: "none",
  cursor: "pointer",
  paddingLeft: 10,
  paddingRight: 10,
  height: 40
};
function Button({ type, style = {}, ...props }) {
  return /* @__PURE__ */ jsx2("button", { type: "button", style: { ...styles, ...style }, ...props });
}

// markup/Input.tsx
import { useState, useEffect } from "react";
import { jsx as jsx3, jsxs } from "react/jsx-runtime";
var wrapperStyles = {
  display: "inline-flex",
  verticalAlign: "top",
  justifyContent: "center",
  flexDirection: "column",
  background: "#EEEEEE",
  paddingLeft: 3,
  paddingRight: 3,
  height: 40
};
var labelStyles = {
  fontSize: 10,
  marginLeft: 3,
  marginBottom: 2
};
var inputStyles = {
  border: "none",
  // borderBottom: '1px solid black',
  background: "none",
  outline: "none"
};
var generateRandomID = () => Math.random().toString(36).substr(2, 9);
function Input({
  id = generateRandomID(),
  value = "",
  style = {},
  onChange,
  onValue,
  ...props
}) {
  const [currentValue, setCurrentValue] = useState(value);
  useEffect(() => {
    setCurrentValue(value);
  }, [value]);
  return /* @__PURE__ */ jsxs("div", { style: { ...wrapperStyles, ...style }, children: [
    /* @__PURE__ */ jsx3("label", { htmlFor: id, style: labelStyles, children: props.label ?? props.placeholder }),
    /* @__PURE__ */ jsx3(
      "input",
      {
        id,
        style: inputStyles,
        ...props,
        value: currentValue,
        onChange: (event) => {
          setCurrentValue(event.target.value);
          if (onValue) {
            onValue(event.target.value);
          }
          if (onChange && typeof onChange === "function") {
            onChange(event);
          }
        }
      }
    )
  ] });
}

// markup/Grid.tsx
import { jsx as jsx4, jsxs as jsxs2 } from "react/jsx-runtime";
var wrapperStyle = {
  display: "flex",
  flexDirection: window.innerWidth < 750 ? "column" : "row"
};
var elementStyle = {
  flex: "1 1 0%"
};
function Grid({ style = {}, children, ...props }) {
  if (!children || !Array.isArray(children) || children.length === 0) {
    return null;
  }
  if (children.length === 1) {
    return /* @__PURE__ */ jsx4("div", { style: { ...wrapperStyle, ...style }, children });
  }
  return /* @__PURE__ */ jsxs2("div", { style: { ...wrapperStyle, ...style }, ...props, children: [
    /* @__PURE__ */ jsx4("div", { style: elementStyle, children: children[0] }),
    /* @__PURE__ */ jsx4("div", { style: elementStyle, children: children[1] })
  ] });
}

// markup/Tabs.tsx
import { useState as useState2 } from "react";
import { Fragment, jsx as jsx5, jsxs as jsxs3 } from "react/jsx-runtime";
var wrapperStyle2 = {
  display: "flex",
  justifyContent: "space-between"
};
var buttonStyles = (active) => ({
  background: "none",
  border: "none",
  outline: "none",
  fontWeight: active ? "bold" : "normal",
  cursor: active ? "auto" : "pointer",
  padding: "10px 0"
});
function Tabs({ labels, children, initialTab = 0, style = {}, onChange, ...props }) {
  const [index, setIndex] = useState2(initialTab);
  if (!children || !Array.isArray(children) || children.length === 0) {
    return null;
  }
  const content = index in children ? children[index] : /* @__PURE__ */ jsx5("p", { children: "Content not found." });
  return /* @__PURE__ */ jsxs3(Fragment, { children: [
    /* @__PURE__ */ jsx5("div", { style: { ...wrapperStyle2, ...style }, ...props, children: labels.map((label, currentIndex) => /* @__PURE__ */ jsx5(
      "button",
      {
        type: "button",
        style: buttonStyles(currentIndex === index),
        onClick: () => {
          setIndex(currentIndex);
          if (typeof onChange === "function") {
            onChange(labels[currentIndex], currentIndex);
          }
        },
        children: label
      },
      currentIndex
    )) }),
    content
  ] });
}

// index.tsx
import { jsx as jsx6, jsxs as jsxs4 } from "react/jsx-runtime";
function Title({ title }) {
  if (typeof title === "string") {
    return /* @__PURE__ */ jsx6("h1", { children: title });
  }
  return title;
}
var wrapperStyles2 = {
  fontFamily: "sans-serif",
  maxWidth: window.innerWidth < 750 ? "95vw" : "75vw",
  margin: "0 auto"
};
var headerStyles = { display: "flex" };
var navStyles = {
  display: "flex",
  flex: 1,
  justifyContent: "flex-end",
  alignItems: "center",
  flexWrap: "wrap"
};
var linkStyles = (end) => ({
  width: 30,
  height: 30,
  marginLeft: end ? 0 : 10,
  display: "block"
});
function Exmpl({ title = "Demo", npm, github, icons, children }) {
  return /* @__PURE__ */ jsxs4("div", { style: wrapperStyles2, children: [
    /* @__PURE__ */ jsxs4("header", { style: headerStyles, children: [
      /* @__PURE__ */ jsx6(Title, { title }),
      /* @__PURE__ */ jsxs4("nav", { style: navStyles, children: [
        icons,
        npm && /* @__PURE__ */ jsx6("a", { href: `https://npmjs.com/${npm}`, children: /* @__PURE__ */ jsx6("img", { alt: "npm Link", style: linkStyles(true), src: npmIcon }) }),
        github && /* @__PURE__ */ jsx6("a", { href: `https://github.com/${github}`, children: /* @__PURE__ */ jsx6("img", { alt: "github Link", style: linkStyles(false), src: githubIcon }) })
      ] })
    ] }),
    children
  ] });
}
export {
  Button,
  Code,
  Exmpl,
  Grid,
  Input,
  Tabs
};
//# sourceMappingURL=index.js.map
